@@ -1,5 +1,11 @@
-# Released under GPLv3+ License
-# Danial Behzadi <dani.behzi@ubuntu.com>, 2020-2024.
+# © 2020-2026 Danial Behzadi <dani.behzi@ubuntu.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """
 real actions of tractor
@@ -7,12 +13,14 @@ real actions of tractor
 
 import os
 import signal
+from shutil import rmtree
 
 from stem.process import launch_tor
 from stem.util import term
 
 from . import checks, control, db, proxy, tractorrc
 
+
 no_color = os.environ["NO_COLOR"] if "NO_COLOR" in os.environ else 0
 
 
@@ -51,8 +59,6 @@ def _finish_notification(verbose: bool) -> None:
             )
         )
     else:
-        if db.get_val("auto-set"):
-            proxy.proxy_set(verbose)
         checks.verbose_print(
             term.format(
                 "Connected",
@@ -61,6 +67,17 @@ def _finish_notification(verbose: bool) -> None:
             ),
             verbose,
         )
+        if db.get_val("auto-set"):
+            proxy.proxy_set(verbose)
+        else:
+            checks.verbose_print(
+                term.format(
+                    "You may set the proxy manually.",
+                    "",
+                    "" if no_color else term.Color.YELLOW,
+                ),
+                verbose,
+            )
 
 
 def _launch(torrc: str, tmpdir: str, verbose: bool) -> None:
@@ -74,6 +91,8 @@ def _launch(torrc: str, tmpdir: str, verbose: bool) -> None:
         tractor_process = launch_tor(
             torrc_path=torrc,
             init_msg_handler=msg_handler,
+            timeout=None,
+            close_output=False,
         )
         db.set_val("pid", tractor_process.pid)
     except OSError as error:
@@ -83,8 +102,8 @@ def _launch(torrc: str, tmpdir: str, verbose: bool) -> None:
     else:
         _finish_notification(verbose)
     finally:
-        os.remove(torrc)
-        os.rmdir(tmpdir)
+        if os.path.exists(tmpdir):
+            rmtree(tmpdir, ignore_errors=True)
 
 
 def _start_launch(verbose: bool) -> None:
