@@ -1,5 +1,11 @@
-# Released under GPLv3+ License
-# Danial Behzadi <dani.behzi@ubuntu.com>, 2020-2024.
+# © 2020-2025 Danial Behzadi <dani.behzi@ubuntu.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """
 module to manages bridges
@@ -16,7 +22,9 @@ def get_sample_bridges() -> str:
     """
     there should be some sample bridges in the package
     """
-    return os.path.dirname(os.path.abspath(__file__)) + "/SampleBridges"
+    return os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), "SampleBridges"
+    )
 
 
 def copy_sample_bridges(bridges_file) -> None:
@@ -26,8 +34,9 @@ def copy_sample_bridges(bridges_file) -> None:
     sample_bridges_file = get_sample_bridges()
     try:
         shutil.copyfile(sample_bridges_file, bridges_file)
-    except Exception as exception:
-        raise IOError from exception
+    except (PermissionError, FileNotFoundError) as exception:
+        raise IOError(f"Bridge copy failed: {exception}") from exception
+    os.chmod(bridges_file, 0o600)
 
 
 def get_file() -> str:
@@ -36,7 +45,7 @@ def get_file() -> str:
     """
     data_dir = db.data_directory()
     os.makedirs(data_dir, mode=0o700, exist_ok=True)
-    bridges_file = data_dir + "/Bridges"
+    bridges_file = os.path.join(data_dir, "Bridges")
     if not os.path.isfile(bridges_file):
         copy_sample_bridges(bridges_file)
     return bridges_file
@@ -67,7 +76,7 @@ def parse_bridge_line(line: str):
     """
     return a dict of transport, addr, id and args for a bridge line
     """
-    if not line:
+    if line.startswith("#") or not line:
         return {"transport": None}
     pattern = re.compile(
         r"""
