@@ -1,5 +1,11 @@
-# Released under GPLv3+ License
-# Danial Behzadi <dani.behzi@ubuntu.com>, 2020-2024.
+# © 2020-2025 Danial Behzadi <dani.behzi@ubuntu.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 """
 actions for tractor internals
@@ -7,6 +13,7 @@ actions for tractor internals
 
 import socket
 import urllib
+from contextlib import contextmanager
 
 import socks
 from gi.repository import Gio
@@ -19,9 +26,10 @@ def running() -> bool:
     """
     checks if Tractor is running or not
     """
-    pid = control.get_pid()
-    if pid:
-        return system.is_running(pid)
+    if system.is_running("tor"):
+        pid = control.get_pid()
+        if pid:
+            return system.is_running(pid)
     return False
 
 
@@ -32,6 +40,22 @@ def _getaddrinfo(*args):
     return [(socket.AF_INET, socket.SOCK_STREAM, 6, "", (args[0], args[1]))]
 
 
+@contextmanager
+def _patch_socket():
+    """
+    Context manager for mokey patching the socket
+    """
+    old_socket = socket.socket
+    old_getaddrinfo = socket.getaddrinfo
+    socket.socket = socks.socksocket
+    socket.getaddrinfo = _getaddrinfo
+    try:
+        yield
+    finally:
+        socket.socket = old_socket
+        socket.getaddrinfo = old_getaddrinfo
+
+
 def _fetched() -> bool:
     """
     Checks if the expected resource fetched or not
@@ -39,19 +63,15 @@ def _fetched() -> bool:
     port = control.get_listener("socks")[1]
     host = "https://check.torproject.org/"
     socks.setdefaultproxy(socks.PROXY_TYPE_SOCKS5, "127.0.0.1", port)
-    old_socket = socket.socket
-    socket.socket = socks.socksocket
-    socket.getaddrinfo = _getaddrinfo
     expectation = "Congratulations."
     err = urllib.error
-    try:
-        with urllib.request.urlopen(host) as request:
-            status = request.status
-            response = request.read().decode("utf=8")
-    except (err.HTTPError, err.URLError, TimeoutError):
-        socket.socket = old_socket
-        return False
-    socket.socket = old_socket
+    with _patch_socket():
+        try:
+            with urllib.request.urlopen(host) as request:
+                status = request.status
+                response = request.read().decode("utf-8")
+        except (err.HTTPError, err.URLError, TimeoutError):
+            return False
     if status == 200 and expectation in response:
         return True
     return False
