@@ -44,7 +44,8 @@ class FillBridgeLines(unittest.TestCase):
         self.assertEqual(
             tractorrc._fill_bridge_lines("obfs4", ["line1", "line2"]),
             "UseBridges 1\n"
-            + "ClientTransportPlugin obfs4 exec obfs4proxy\n"
+            + "ClientTransportPlugin meek_lite,obfs2,obfs3,obfs4,scramblesuit"
+            + ",webtunnel exec obfs4proxy\n"
             + "Bridge line1\n"
             + "Bridge line2\n",
         )
@@ -58,13 +59,10 @@ class FillBridgeLines(unittest.TestCase):
             tractorrc._fill_bridge_lines("snowflake", ["line1", "line2"]),
             "UseBridges 1\n"
             + "ClientTransportPlugin snowflake exec snowflake "
-            + "-url https://snowflake-broker.torproject.net.global.prod."
-            + "fastly.net/ -front foursquare.com -ice "
-            + "stun:stun.l.google.com:19302,stun:stun.antisip.com:3478,"
-            + "stun:stun.bluesip.net:3478,stun:stun.dus.net:3478,"
-            + "stun:stun.epygi.com:3478,stun:stun.sonetel.net:3478,"
+            + "-ice stun:stun.antisip.com:347,stun:stun.epygi.com:3478,"
             + "stun:stun.uls.co.za:3478,stun:stun.voipgate.com:3478,"
-            + "stun:stun.voys.nl:3478\n"
+            + "stun:stun.mixvoip.com:3478,stun:stun.nextcloud.com:3478,"
+            + "stun:stun.bethesda.net:3478,stun:stun.nextcloud.com:443\n"
             + "Bridge line1\n"
             + "Bridge line2\n",
         )
@@ -97,7 +95,9 @@ class Create(unittest.TestCase):
     test case for create
     """
 
+    @patch("tractor.tractorrc._get_upstream_line", return_value="")
     @patch("tractor.db.get_val", return_value="none")
+    @patch("os.chmod")
     def test_local(self, *_):
         """
         local connection
@@ -107,8 +107,10 @@ class Create(unittest.TestCase):
         self.assertTrue(path.endswith("/tractorrc"))
 
     @patch("tractor.tractorrc._get_bridge_lines", return_value=None)
+    @patch("tractor.tractorrc._get_upstream_line", return_value="")
     @patch("tractor.bridges.relevant_lines", return_value=None)
     @patch("tractor.db.get_val", return_value=True)
+    @patch("os.chmod")
     def test_network(self, *_):
         """
         listen on network
